const Mesa = require('vendor/Mesa.js');

/**
 * A Mesa Script exports a class with a script() method.
 */
module.exports = new class {

  /**
   * Mesa Script
   *
   * @param {object} payload The payload data
   * @param {object} context Additional context about this task
   */
  script = (payload, context) => {
    let order = context.steps.shopify;
    let tagRecords = [];
    for (let tag of order.tags.split(', ')) {
      let tagRecord = this.findOrCreateTagByName(tag); 
      tagRecords.push(tagRecord);
    }

    Mesa.output.next(tagRecords);
  }

  findOrCreateTagByName = (tagName) => { 
    // Add your custom code here
    let options = {
      "headers": {
        "Content-Type": "application\/json",
        "Authorization": "Bearer " + Mesa.credential.get('airtable'),
      }
    }

    let filterByFormula = `{Name} = '${tagName}'`;
    let base = context.steps.transform.base;
    let table = context.steps.transform.table;
    let url = 'https://api.airtable.com/v0/' + base + '/' + table + '?filterByFormula=' + encodeURIComponent(filterByFormula);

    let results = Mesa.request.get(url, options);    
    Mesa.log.info("results", results);

    let record = {};
    if (results.records.length > 0) {
      return results.records[0];
    } 
    
    let data = {
      "records": [
        {
          "fields": {
            "Name": tagName,
          },
        }
      ],
      "typecast": true,
    }
    let result = Mesa.request.post(url, data, options);
    Mesa.log.info('result', result);
    record = result.records[0];

    return record;
  }
}
